#include <string>
#include "defines.h"
#include "frend.h"
#include "misc.h"
#include "skins.h"

#ifndef S9X_EXTRA_H
#define S9X_EXTRA_H

class s9x_Snapshot :    public s9x_Notepage
{
 private:
   fr_Label		Desc;
   fr_File		File;
   void			EventOccurred(fr_Event*e);
 public:
	                s9x_Snapshot(fr_Notebook*parent);
   void			FilePopup();
};

class s9x_Extra :       public s9x_Notepage
{
 protected:
   std::string		ArgStr;
   fr_Label		Desc;
   fr_Text         	Options;
   void			EventOccurred(fr_Event*e);
 public:
	                s9x_Extra(fr_Notebook*parent);
   void            	SetToDefaults();
   void            	SiftArgs(fr_ArgList& L);
   void			CompileArgs(fr_ArgList& L);
};

void s9x_RandomTip();

#endif
